@@ -1,14 +1,12 @@
 package SOAP::WSDL::Transport::HTTP;
-use strict; use warnings;
+use strict;
 use base qw(LWP::UserAgent);
 
-use version; our $VERSION = qv('2.00.09');
-
 # create methods normally inherited from SOAP::Client
 SUBFACTORY: {
     no strict qw(refs);
     foreach my $method ( qw(code message status is_success) ) {
-        *{ $method } = sub {
+        *{ $method } = sub { 
             my $self = shift;
             return $self->{ $method } if not @_;
             return $self->{ $method } = shift;
@@ -16,21 +14,18 @@ SUBFACTORY: {
     }
 }
 
-sub _agent {
-    return qq[SOAP::WSDL $VERSION];
-}
-
 sub send_receive {
     my ($self, %parameters) = @_;
     my ($envelope, $soap_action, $endpoint, $encoding, $content_type) =
         @parameters{qw(envelope action endpoint encoding content_type)};
 
-    $encoding = defined($encoding)
-        ? lc($encoding)
-        : 'utf-8';
+    $encoding = defined($encoding) 
+        ? 'utf8' 
+        : lc($encoding);
 
-    $content_type = "text/xml; charset=$encoding"
-        if not defined($content_type);
+    # TODO check whether we need this with current LWP::UserAgent - we're 
+    # not here to fix LWP::UserAgent bugs...
+    #
     # what's this all about?
     # unfortunately combination of LWP and Perl 5.6.1 and later has bug
     # in sending multibyte characters. LWP uses length() to calculate
@@ -48,25 +43,33 @@ sub send_receive {
 
     # use bytes is lexically scoped
     my $bytelength = do { use bytes; length $envelope };
-    $envelope = pack('C0A*', $envelope)
+    $envelope = pack('C0A*', $envelope) 
         if length($envelope) != $bytelength;
 
+    # END TODO
+
     my $request = HTTP::Request->new( 'POST',
         $endpoint,
-        [   'Content-Type', "$content_type",
+        [   'Content-Type', "$content_type; charset=$encoding",
             'Content-Length', $bytelength,
             'SOAPAction', $soap_action,
         ],
         $envelope );
-
+  
+    use Data::Dumper;
+    warn Dumper $request;
+  
     my $response = $self->request( $request );
 
+    warn Dumper $response;
+
+
     $self->code( $response->code);
     $self->message( $response->message);
     $self->is_success($response->is_success);
     $self->status($response->status_line);
-
-    return $response->content();
+    
+    return $response->content();    
 }
 
 1;
@@ -79,14 +82,14 @@ SOAP::WSDL::Transport::HTTP - Fallback http(s) transport class
 
 =head1 DESCRIPTION
 
-Provides a thin transport class used by SOAP::WSDL::Transport when
+Provides a thin transport class used by SOAP::WSDL::Transport when 
 SOAP::Lite is not available.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 LICENSE
 
-Copyright (c) 2007 Martin Kutter. All rights reserved.
+Copyright 2004-2007 Martin Kutter.
 
-This file is part of SOAP-WSDL. You may distribute/modify it under
+This file is part of SOAP-WSDL. You may distribute/modify it under 
 the same terms as perl itself
 
 =head1 AUTHOR
@@ -95,10 +98,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 805 $
+ $Rev: 176 $
  $LastChangedBy: kutterma $
- $Id: HTTP.pm 805 2009-02-23 21:12:24Z kutterma $
+ $Id: HTTP.pm 176 2007-08-31 15:28:29Z kutterma $
  $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Transport/HTTP.pm $
-
+ 
 =cut
 
