@@ -24,26 +24,3 @@ BEGIN {
 };
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-SOAP::WSDL::XSD::Typelib::Builtin::int - int objects
-
-=head1 DESCRIPTION
-
-Subclass of long.
-
-=head1 LICENSE
-
-This file is part of SOAP-WSDL. You may distribute/modify it under 
-the same terms as perl itself
-
-=head1 AUTHOR
-
-Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
-
-=cut
\ No newline at end of file
